@@ -5,5 +5,10 @@ from watson.framework.views.renderers import abc
 
 class Renderer(abc.Renderer):
 
+    encoder = None
+
+    def __init__(self):
+        self.encoder = JSONEncoder()
+
     def __call__(self, view_model, context=None):
-        return JSONEncoder().encode(view_model.data)
+        return self.encoder.encode(view_model.data)
